/**
 *
 */
package jp.agentec.sinaburocast.action.admin.member;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.text.ParseException;
import java.util.List;

import org.apache.log4j.Logger;
import org.seasar.framework.util.StringUtil;
import org.seasar.struts.annotation.ActionForm;
import org.seasar.struts.annotation.Execute;
import org.seasar.struts.util.ResponseUtil;

import jp.agentec.sinaburocast.action.AbstractAction;
import jp.agentec.sinaburocast.common.SinaburoConstant;
import jp.agentec.sinaburocast.common.annotation.OperationHistoryAno;
import jp.agentec.sinaburocast.common.util.SinaburoUtil;
import jp.agentec.sinaburocast.common.util.SinaburoViewUtil;
import jp.agentec.sinaburocast.dto.MemberReportDto;
import jp.agentec.sinaburocast.form.admin.member.MemberReportForm;
import jp.agentec.sinaburocast.service.MemberService;


/**
 *
 * 会員情報分析
 * @author kim-hs
 *
 */
public class MemberReportAction extends AbstractAction {

	private final Logger logger = Logger.getLogger(getClass());

	@ActionForm
	public MemberReportForm memberReportForm;

	public MemberService memberService;

	/**
	 * 初期表示
	 */
	@Execute(validator = false)
	public String index() {

		memberReportForm.kubun = "0";
		session.removeAttribute("reportList");

		return "/admin/member/memberReport.html";
	}

	/**
	 * レポート検索
	 * @throws ParseException
	 */
	@Execute(validator = false)
	public String memberReportSearch() throws ParseException {

		List<MemberReportDto> list = null;//memberService.findByMemberReportList();

		if(StringUtil.isNotBlank(memberReportForm.fromDay) && !SinaburoUtil.checkDate(memberReportForm.fromDay)){
			addErrorMessage("dateError", "errors.E033");
			addErrorMessage("dateError_1", "errors.E033_1");
			addErrorMessage("dateError_2", "errors.E033_2");
			return "/admin/member/memberReport.html";
		}else if(StringUtil.isNotBlank(memberReportForm.toDay) && !SinaburoUtil.checkDate(memberReportForm.toDay)){
			addErrorMessage("dateError", "errors.E033");
			addErrorMessage("dateError_1", "errors.E033_1");
			addErrorMessage("dateError_2", "errors.E033_2");
			return "/admin/member/memberReport.html";
		}else if(StringUtil.isNotBlank(memberReportForm.fromDay) && StringUtil.isNotBlank(memberReportForm.toDay)
				&& memberReportForm.toDay.compareTo(memberReportForm.fromDay) < 0
				){
			addErrorMessage("dateError", "errors.E020");
			return "/admin/member/memberReport.html";
		}

		//月別
		if (memberReportForm.kubun.equals("0")) {
			list = memberService.findByMemberReportList();
		} else {
			if (StringUtil.isBlank(memberReportForm.fromDay)) {
				addError(SinaburoViewUtil.getMessage("errors.E017"));
				return "/admin/member/memberReport.html";
			}

			if (StringUtil.isBlank(memberReportForm.toDay)) {
				addError(SinaburoViewUtil.getMessage("errors.E018"));
				return "/admin/member/memberReport.html";
			}

			if (SinaburoUtil.differenceDays(memberReportForm.toDay,memberReportForm.fromDay) > 90) {
				addError(SinaburoViewUtil.getMessage("errors.E019"));
				return "/admin/member/memberReport.html";
			}

			if (SinaburoUtil.differenceDays(memberReportForm.toDay,memberReportForm.fromDay) < 0) {
				addError(SinaburoViewUtil.getMessage("errors.E020"));
				return "/admin/member/memberReport.html";
			}

			list = memberService.findByMemberReportListDay(memberReportForm);
		}

		session.setAttribute("reportList", list);
		return "/admin/member/memberReport.html";
	}

	/**
	 * 分析レポートダウンロード
	 * @return
	 * @throws UnsupportedEncodingException
	 * @throws Exception
	 */
	@Execute(validator=false)
	@OperationHistoryAno(operationTypeId=SinaburoConstant.OperationType.DOWNLOAD,target="分析レポート出力",detail="ダウンロード",screenId=SinaburoConstant.screenId.CMM0008)
	public String reportDownload() throws UnsupportedEncodingException, Exception {

		StringBuffer str = new StringBuffer();
		str.append("\"\"\t\"全体\"\t\"\"\t\"\"\t\"E-mail(メイン)\"\t\"\"\t\"\"\t\"E-mail(サブ)\"\t\"\"\t\"\"\r\n");
		str.append("\"日付\"\t\"登録者\"\t\"退会者\"\t\"純増者\"\t\"登録者\"\t\"退会者\"\t\"純増者\"\t\"登録者\"\t\"退会者\"\t\"純増者\"\r\n");

        @SuppressWarnings("unchecked")
		List<MemberReportDto> list = (List<MemberReportDto>) session.getAttribute("reportList");

    	for (MemberReportDto report : list) {

    		str.append("\""+ report.date+"\"\t\"");
    		str.append(report.total+"\"\t\""+report.totalT+"\"\t\""+report.totalUp+"\"\t\"");
    		str.append(report.pcTotal+"\"\t\""+report.pcTotalt+"\"\t\""+report.pcTotalUp+"\"\t\"");
    		str.append(report.mbTotal+"\"\t\""+report.mbTotalt+"\"\t\""+report.mbTotalUp+"\"\r\n");

    	}

    	//20170508 SJIS文字化け対応
    	String outStr = str.toString();
		outStr = SinaburoUtil.toSJIS(outStr);
		ResponseUtil.download(URLEncoder.encode("member_report.tsv", "UTF-8"), outStr.getBytes("Windows-31J"));
		//ResponseUtil.download(URLEncoder.encode("member_report.tsv", "UTF-8"), str.toString().getBytes("Shift_JIS"));
		//response.setContentType("Content-Type content=\"text/html; charset=\"UTF-8\"");
		return null;

	}
}
