/**
 * 独自に作成したVelocityToolを置くパッケージ.
 */
package jp.agentec.sinaburocast.common.util.velocity;


/**
 * SinaburoCast用HTMLエスケープ VelocityTools.
 *
 * applicationスコープに置いて用いる
 *
 * @author arima
 */
public class SinaburoEscapeTool {
	/**
	 * 引数をエスケープして返す.
	 *
	 * 既存の変換メソッドには以下の問題があるため使用しない。
	 * {@link org.apache.velocity.tools.generic.EscapeTool#html(Object)} はシングルクォートをエスケープしない。
	 * また全ての漢字をエスケープしてしまうため、ソースを表示させても何が書いてあるか分からなくなってしまう。
	 * {@link org.apache.velocity.tools.generic.EscapeTool#xml(Object)} は必要な文字のみエスケープする。
	 * シングルクォートは<pre>"&apos;"</pre>に置換されるが、IEはこれをそのまま表示してしまう。(Firefox, ChromeはOK)
	 *
	 * @param str
	 * @return エスケープされた文字列
	 */
	public String html(Object str0) {
		if (str0 == null)	return	null;
		String str = str0.toString();
		
		StringBuilder sb = new StringBuilder();
		for (int i = 0 ; i < str.length() ; i++) {
			final char c = str.charAt(i);
			switch (c) {
			case '"':
				sb.append("&quot;");
				break;
			case '&':
				sb.append("&amp;");
				break;
			case '<':
				sb.append("&lt;");
				break;
			case '>':
				sb.append("&gt;");
				break;
			case '\'':
				sb.append("&#39;");
				break;
			default:
				sb.append(c);
			}
		}
		return sb.toString();
	}
	
	/**
	 * 指定の文字数以上の場合に略記する
	 * @param str
	 * @param length
	 * @return
	 */
	public String briefEscape(Object str0, int length){
		if (str0 == null)	return	null;
		String str = str0.toString();
		
		if (str.length() > length) {
			return	html(str.substring(0, length)) + "...";
		} else {
			return	html(str);
		}
	}
	
	/**
	 * Renders a hash (#).
	 * @return a hash (#).
	 *
	 * {@link org.apache.velocity.tools.generic.EscapeTool#getHash()} から借用
	 */
	public String getHash()
	{
		return "#";
	}
}
